# Generated by Django 5.2.11 on 2026-02-18 09:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('moses', '0003_customuser_google_sub'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customuser',
            name='preferred_language',
            field=models.CharField(choices=[('en', 'English'), ('ru', 'Russian'), ('kg', 'Kyrgyz')], default='en', max_length=10, verbose_name='Preferred language'),
        ),
    ]
