# Generated by Django 5.2.11 on 2026-03-17 15:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('moses', '0004_alter_customuser_preferred_language'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customuser',
            name='email',
            field=models.EmailField(blank=True, max_length=254),
        ),
        migrations.AlterField(
            model_name='customuser',
            name='preferred_language',
            field=models.CharField(choices=[('en', 'English')], default='en', max_length=10, verbose_name='Preferred language'),
        ),
    ]
